==> savane-3.12.tar.gz: savane-3.12/frontend/site-specific/nongnu/forbidden_group_names.php <==
<?php
# Savannah - Forbidden group names
#
# Copyright (C) 1999, 2000 The SourceForge Crew
# Copyright (C) 2000-2006 Mathieu Roy
# Copyright (C) 2014, 2016, 2017 Assaf Gordon
# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
# Copyright (C) 2013, 2014, 2017-2023 Ineiev <ineiev@gnu.org>
#
# This file is part of Savane.
#
# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
# under the terms of the GNU General Public license version 3 or (at your
# option) any later version; further contributions are covered by
# the GNU Affero General Public license version 3 or (at your option)
# any later version.  The license notices for the AGPL and the GPL follow.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#    You can fed $specific_forbid_group_regexp by a perl regexp
#    with group names you want to forbid on your system.
#
#    It means that it will not possible to register a project with a name
#    that match that list.
#
#    This would constitue an additional list of group name to forbid.
#    If you want the system to only take account of that list, not to
#    take account of the Savannah hardcoded list, set the variable
#    	 $only_specific_forbid_group_regexp = 1;
#


// The perl regexp:
//    The two slashes (/ /) are mandatory, see the preg_match manual.
$GLOBALS['specific_forbid_group_regexp'] = 0;

// Disregard the Savannah default list (dangerous)
$GLOBALS['only_specific_forbid_group_regexp'] = 0;

?>

==> savane-3.14.tar.gz: savane-3.14/frontend/site-specific/nongnu/forbidden_group_names.php <==
<?php
# Savannah - Forbidden group names
#
# Copyright (C) 1999, 2000 The SourceForge Crew
# Copyright (C) 2000-2006 Mathieu Roy
# Copyright (C) 2014, 2016, 2017 Assaf Gordon
# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
# Copyright (C) 2013, 2014, 2017-2024 Ineiev <ineiev@gnu.org>
#
# This file is part of Savane.
#
# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
# under the terms of the GNU General Public license version 3 or (at your
# option) any later version; further contributions are covered by
# the GNU Affero General Public license version 3 or (at your option)
# any later version.  The license notices for the AGPL and the GPL follow.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#    You can fed $specific_forbid_group_regexp by a perl regexp
#    with group names you want to forbid on your system.
#
#    It means that it will not possible to register a project with a name
#    that match that list.
#
#    This would constitute an additional list of group name to forbid.
#    If you want the system to only take account of that list, not to
#    take account of the Savannah hardcoded list, set the variable
#    	 $only_specific_forbid_group_regexp = 1;
#


// The perl regexp:
//    The two slashes (/ /) are mandatory, see the preg_match manual.
$GLOBALS['specific_forbid_group_regexp'] = 0;

// Disregard the Savannah default list (dangerous)
$GLOBALS['only_specific_forbid_group_regexp'] = 0;

?>
